To execute linux files 

-  code should be like . ./rund_docker_dev.sh
-  The extra . is so that all commands are runnning on the same shelll and no subshells are use

To run on windows 

- Directly run the bat file